@@ -16,38 +16,38 @@
 import itertools
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon.utils import functions as utils
 from horizon.utils import memoized
 from keystoneauth1.identity.generic import token
 from keystoneauth1 import session as ks_session
-from masakariclient import api_versions
-from masakariclient import plugin
 from openstack import connection
 from openstack_dashboard.api import nova as nova_api
 
 from masakaridashboard.handle_errors import handle_errors
 
-MICROVERSION_FEATURES = {"recovery_workflow_details": ["1.1"]}
-
 
 @memoized.memoized
 def openstack_connection(request, version=None):
+    interface = getattr(settings, 'OPENSTACK_ENDPOINT_TYPE', 'publicURL')
+
     auth = token.Token(
-        auth_url=getattr(settings, 'OPENSTACK_KEYSTONE_URL'),
+        auth_url=request.user.endpoint,
         token=request.user.token.id,
         project_name=request.user.project_name,
         project_id=request.user.tenant_id)
-    session = ks_session.Session(auth=auth)
+    cacert = getattr(settings, 'OPENSTACK_SSL_CACERT')
+    session = ks_session.Session(auth=auth, verify=cacert or True)
     conn = connection.Connection(session=session,
+                                 interface=interface,
                                  ha_api_version=version)
 
     return conn.instance_ha
 
 
-def get_hypervisor_list(request):
-    return nova_api.hypervisor_list(request)
+def get_compute_service_list(request):
+    return nova_api.service_list(request, binary="nova-compute")
 
 
 @handle_errors(_("Unable to retrieve segments"), [])
@@ -183,51 +183,30 @@ def notification_list(request, filters=None, marker='', paginate=False):
     return entities, has_more_data, has_prev_data
 
 
+def get_notification_list(request):
+    """return notifications list """
+    return list(openstack_connection(request).notifications())
+
+
 def get_notification(request, notification_id):
     """return single notifications"""
     return openstack_connection(request).get_notification(notification_id)
 
 
-def get_requested_versions(features):
-    if not features:
-        return None
-    # Convert a single feature string into a list for backward compatibility.
-    if isinstance(features, str):
-        features = [features]
-    service_features = MICROVERSION_FEATURES
-    feature_versions = set(service_features[features[0]])
-    for feature in features[1:]:
-        feature_versions &= set(service_features[feature])
-    if not feature_versions:
-        return None
-    # Sort version candidates from larger versins
-    feature_versions = sorted(feature_versions, reverse=True,
-                              key=lambda v: [int(i) for i in v.split('.')])
-    return feature_versions
-
-
-def get_microversion_for_features(features, wrapper_class, min_ver, max_ver):
-    """Retrieves that highest known functional microversion for features"""
-    feature_versions = get_requested_versions(features)
-    if not feature_versions:
-        return None
-    for version in feature_versions:
-        microversion = wrapper_class(version)
-        if microversion.matches(min_ver, max_ver):
-            return microversion
-    return None
-
-
-@memoized.memoized
-def get_microversion(features):
-    min_ver = api_versions.APIVersion(plugin.SUPPORTED_VERSIONS[1])
-    max_ver = api_versions.APIVersion(plugin.SUPPORTED_VERSIONS[-1])
-    return (get_microversion_for_features(
-        features, api_versions.APIVersion, min_ver, max_ver))
-
-
 def get_notification_with_progress_details(request, notification_id):
-    microversion = get_microversion("recovery_workflow_details")
     return openstack_connection(
-        request, version=microversion.get_string()).get_notification(
+        request, version='1.1').get_notification(
         notification_id)
+
+
+@handle_errors(_("Unable to get vmoves list"), [])
+def get_vmoves_list(request, notification_id, filters):
+    """return vmoves list """
+    return openstack_connection(
+        request, version='1.3').vmoves(notification_id, **filters)
+
+
+def get_vmove(request, notification_id, vmove_id):
+    """return single vmove"""
+    return openstack_connection(
+        request, version='1.3').get_vmove(vmove_id, notification_id)
